# Intel Boards

The {py:mod}`torii.platform.vendor.altera` module provides a base platform to support Intel toolchains with the [Quartus] and [Mistral] toolchains.

```{eval-rst}
.. automodule:: torii_boards.altera.arrow_deca
  :members:

.. automodule:: torii_boards.altera.chameleon96
  :members:

.. automodule:: torii_boards.altera.de0_cv
  :members:

.. automodule:: torii_boards.altera.de0
  :members:

.. automodule:: torii_boards.altera.de1_soc
  :members:

.. automodule:: torii_boards.altera.de10_lite
  :members:

.. automodule:: torii_boards.altera.de10_nano
  :members:

.. automodule:: torii_boards.altera.mister
  :members:

.. automodule:: torii_boards.altera.rz_easyfpga_a2_2
  :members:

```

[Quartus]: https://www.intel.com/content/www/us/en/products/details/fpga/development-tools/quartus-prime.html
[Mistral]: https://github.com/Ravenslofty/mistral
